==========================================
KEMPtechnologies OpenStack LBaaS Driver V2
==========================================

This LBaaS driver for OpenStack acts as an interface between
OpenStack and KEMP Technologies LoadMaster appliances.

============
Contributors
============

Shane McGough, KEMP Technologies
